@@ -1,3 +1,5 @@
+from __future__ import annotations
+
 import os
 import pickle
 import signal
@@ -34,10 +36,7 @@ SDIR = os.path.dirname(os.path.abspath(__file__))
 
 class TestLocalPopen:
     def test_contextmanager(self):
-        if IS_WIN32:
-            command = ["dir"]
-        else:
-            command = ["ls"]
+        command = ["dir"] if IS_WIN32 else ["ls"]
         with PlumbumLocalPopen(command):
             pass
 
@@ -48,13 +47,14 @@ class TestLocalPath:
     def test_name(self):
         name = self.longpath.name
         assert isinstance(name, str)
-        assert "file.txt" == str(name)
+        assert str(name) == "file.txt"
 
     def test_dirname(self):
         name = self.longpath.dirname
         assert isinstance(name, LocalPath)
-        assert "/some/long/path/to" == str(name).replace("\\", "/").lstrip("C:").lstrip(
-            "D:"
+        assert (
+            str(name).replace("\\", "/").lstrip("C:").lstrip("D:")
+            == "/some/long/path/to"
         )
 
     def test_uri(self):
@@ -63,7 +63,7 @@ class TestLocalPath:
             assert pth.startswith("file:///")
             assert pth.endswith(":/some/long/path/to/file.txt")
         else:
-            assert "file:///some/long/path/to/file.txt" == self.longpath.as_uri()
+            assert self.longpath.as_uri() == "file:///some/long/path/to/file.txt"
 
     def test_pickle(self):
         path1 = local.path(".")
@@ -326,9 +326,7 @@ class TestLocalMachine:
             local["non_exist1N9"]()
 
         with pytest.raises(ImportError):
-            from plumbum.cmd import non_exist1N9
-
-            assert non_exist1N9
+            from plumbum.cmd import non_exist1N9  # noqa: F401
 
     def test_pathlib(self):
         ls_path = Path(local.which("ls"))
@@ -347,17 +345,16 @@ class TestLocalMachine:
 
     def test_shadowed_by_dir(self):
         real_ls = local["ls"]
-        with local.tempdir() as tdir:
-            with local.cwd(tdir):
-                ls_dir = tdir / "ls"
-                ls_dir.mkdir()
-                fake_ls = local["ls"]
-                assert fake_ls.executable == real_ls.executable
+        with local.tempdir() as tdir, local.cwd(tdir):
+            ls_dir = tdir / "ls"
+            ls_dir.mkdir()
+            fake_ls = local["ls"]
+            assert fake_ls.executable == real_ls.executable
 
-                local.env.path.insert(0, tdir)
-                fake_ls = local["ls"]
-                del local.env.path[0]
-                assert fake_ls.executable == real_ls.executable
+            local.env.path.insert(0, tdir)
+            fake_ls = local["ls"]
+            del local.env.path[0]
+            assert fake_ls.executable == real_ls.executable
 
     def test_repr_command(self):
         assert "BG" in repr(BG)
@@ -514,7 +511,7 @@ class TestLocalMachine:
     def test_run(self):
         from plumbum.cmd import grep, ls
 
-        rc, out, err = (ls | grep["non_exist1N9"]).run(retcode=1)
+        rc, _out, _err = (ls | grep["non_exist1N9"]).run(retcode=1)
         assert rc == 1
 
     def test_timeout(self):
@@ -530,7 +527,7 @@ class TestLocalMachine:
         cat["/dev/urndom"] & FG(1)
         assert "urndom" in capfd.readouterr()[1]
 
-        assert "" == capfd.readouterr()[1]
+        assert capfd.readouterr()[1] == ""
 
         (cat["/dev/urndom"] | head["-c", "10"]) & FG(retcode=1)
         assert "urndom" in capfd.readouterr()[1]
@@ -549,7 +546,7 @@ class TestLocalMachine:
         from plumbum.cmd import bash
 
         cmd = bash["-ce", "for ((i=0;1==1;i++)); do echo $i; sleep .3; done"]
-        with pytest.raises(ProcessTimedOut):
+        with pytest.raises(ProcessTimedOut):  # noqa: PT012
             for i, (out, err) in enumerate(cmd.popen().iter_lines(timeout=1)):
                 assert not err
                 assert out
@@ -576,7 +573,7 @@ class TestLocalMachine:
         ]
         types = {1: "out:", 2: "err:"}
         counts = {1: 0, 2: 0}
-        with pytest.raises(ProcessTimedOut):
+        with pytest.raises(ProcessTimedOut):  # noqa: PT012
             # Order is important on mac
             for typ, line in cmd.popen().iter_lines(timeout=1, mode=BY_TYPE):
                 counts[typ] += 1
@@ -588,7 +585,7 @@ class TestLocalMachine:
     def test_iter_lines_error(self):
         from plumbum.cmd import ls
 
-        with pytest.raises(ProcessExecutionError) as err:
+        with pytest.raises(ProcessExecutionError) as err:  # noqa: PT012
             for i, _lines in enumerate(ls["--bla"].popen()):  # noqa: B007
                 pass
             assert i == 1
@@ -603,7 +600,7 @@ class TestLocalMachine:
 
         cmd = bash["-ce", "for ((i=0;1==1;i++)); do echo $i; sleep $i; done"]
 
-        with pytest.raises(ProcessLineTimedOut):
+        with pytest.raises(ProcessLineTimedOut):  # noqa: PT012
             # Order is important on mac
             for i, (out, err) in enumerate(cmd.popen().iter_lines(line_timeout=0.2)):
                 print(i, "out:", out)
@@ -612,7 +609,7 @@ class TestLocalMachine:
 
     @skip_on_windows
     def test_modifiers(self):
-        from plumbum.cmd import grep, ls
+        from plumbum.cmd import cat, grep, ls
 
         f = (ls["-a"] | grep["\\.py"]) & BG
         f.wait()
@@ -620,11 +617,17 @@ class TestLocalMachine:
 
         command = ls["-a"] | grep["local"]
         command_false = ls["-a"] | grep["not_a_file_here"]
+        command_false_2 = command_false | cat
         command & FG
         assert command & TF
         assert not (command_false & TF)
+        assert not (command_false_2 & TF)
         assert command & RETCODE == 0
         assert command_false & RETCODE == 1
+        assert command_false_2 & RETCODE == 1
+        assert (command & TEE)[0] == 0
+        assert (command_false & TEE(retcode=None))[0] == 1
+        assert (command_false_2 & TEE(retcode=None))[0] == 1
 
     @skip_on_windows
     def test_tee_modifier(self, capfd):
@@ -632,7 +635,7 @@ class TestLocalMachine:
 
         result = echo["This is fun"] & TEE
         assert result[1] == "This is fun\n"
-        assert "This is fun\n" == capfd.readouterr()[0]
+        assert capfd.readouterr()[0] == "This is fun\n"
 
     @skip_on_windows
     def test_tee_race(self, capfd):
@@ -642,11 +645,11 @@ class TestLocalMachine:
         for _ in range(5):
             result = seq["1", "5000"] & TEE
             assert result[1] == EXPECT
-            assert EXPECT == capfd.readouterr()[0]
+            assert capfd.readouterr()[0] == EXPECT
 
     @skip_on_windows
     @pytest.mark.parametrize(
-        "modifier, expected",
+        ("modifier", "expected"),
         [
             (FG, None),
             (TF(FG=True), True),
@@ -814,7 +817,7 @@ class TestLocalMachine:
         assert list(local.pgrep("[pP]ython"))
 
     def _generate_sigint(self):
-        with pytest.raises(KeyboardInterrupt):
+        with pytest.raises(KeyboardInterrupt):  # noqa: PT012
             if sys.platform == "win32":
                 from win32api import GenerateConsoleCtrlEvent
 
@@ -907,16 +910,14 @@ except PidFileTaken:
         num_of_procs = 20
         num_of_increments = 20
 
-        code = """from plumbum.fs.atomic import AtomicCounterFile
+        code = f"""from plumbum.fs.atomic import AtomicCounterFile
 import time
 time.sleep(0.2)
 afc = AtomicCounterFile.open("counter")
-for _ in range({}):
+for _ in range({num_of_increments}):
     print(afc.next())
     time.sleep(0.1)
-""".format(
-            num_of_increments,
-        )
+"""
 
         procs = []
         for _ in range(num_of_procs):
@@ -1024,7 +1025,7 @@ for _ in range({}):
 
         result = echo["This is fun"].run_tee()
         assert result[1] == "This is fun\n"
-        assert "This is fun\n" == capfd.readouterr()[0]
+        assert capfd.readouterr()[0] == "This is fun\n"
 
     def test_run_tf(self):
         from plumbum.cmd import ls
@@ -1053,10 +1054,6 @@ class TestLocalEncoding:
     except NameError:
         richstr = chr(40960)
 
-    @pytest.mark.xfail(
-        IS_WIN32,
-        reason="Unicode output on Windows does not work (Python 3.6+ was supposed to work)",
-    )
     def test_inout_rich(self):
         from plumbum.cmd import echo
 
